<?php

/**
 * Part of the Antares package.
 *
 * NOTICE OF LICENSE
 *
 * Licensed under the 3-clause BSD License.
 *
 * This source file is subject to the 3-clause BSD License that is
 * bundled with this package in the LICENSE file.
 *
 * @package    Automation
 * @version    0.9.0
 * @author     Antares Team
 * @license    BSD License (3-clause)
 * @copyright  (c) 2017, Antares
 * @link       http://antaresproject.io
 */

namespace Antares\Automation\Model\TestCase;

use Antares\Automation\Model\JobResults;
use Antares\Automation\Model\Jobs as Model;
use Antares\Brands\Model\Brands;
use Antares\Model\Component;
use Antares\Support\Traits\Testing\EloquentConnectionTrait;
use Antares\Testing\TestCase;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\Relations\HasOne;

class JobsTest extends TestCase
{

    use EloquentConnectionTrait;

    /**
     * @var Brands
     */
    private $model;

    /**
     * Setup the test environment.
     */
    public function setUp()
    {
        parent::setUp();
        $model       = new Model();
        $this->addMockConnection($model);
        $this->model = $model;
    }

    /**
     * Teardown the test environment.
     */
    public function tearDown()
    {
        parent::tearDown();
    }

    /**
     * has timestamps
     */
    public function testHasTimestamps()
    {
        $this->assertTrue($this->model->timestamps);
    }

    /**
     * has valid morph class
     */
    public function testHasValidMorhClass()
    {
        $this->assertSame($this->model->getMorphClass(), 'Antares\Automation\Model\Jobs');
    }

    /**
     * has valid table name
     */
    public function testHasValidTableName()
    {
        $this->assertSame('tbl_jobs', $this->model->getTable());
    }

    /**
     * has valid relation to job results table
     */
    public function testJobResults()
    {
        $jobResults = $this->model->jobResults();
        $this->assertInstanceOf(HasMany::class, $jobResults);
        $this->assertInstanceOf(JobResults::class, $jobResults->getModel());
    }

    /**
     * has valid relation to component table
     */
    public function testComponent()
    {
        $component = $this->model->component();
        $this->assertInstanceOf(HasOne::class, $component);
        $this->assertInstanceOf(Component::class, $component->getModel());
    }

}
